/*
 * @author: Alex Cappiello
 * @date: 4/6/2012
 *
 * This file is intended to highlight the fact that C does not include bools as
 * a standard type. We can simulate these with stdbool.h, which just define
 * false as 0 and true as 1. As far as behavior is concerned, we can think of
 * false as 0 and true as not 0. Stop for a moment to think about what this
 * means.
 *
 * These all are "true": 1, 2, 100, INT_MAX, -5, 'a', 'Q', etc.
 * And these are "false": 0, '\0', etc.
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <string.h>

int main() {
  bool b = true;
  if (b)
    printf("bool b is true!\n");
  if (-5)
    printf("-5 is true!\n");

  // Don't worry about this declaration.
  const char x[] = "Hello World!!";

  char *s = calloc(strlen(x) + 1, sizeof(char));
  
  /* This block of code probably looks really strange. Run it, then take some
   * time to think about what is happening here.
   */
  char *p = s;
  char *q = (char*)&x; // '&' gets the address of a local var.
  while (*p++ = *q++) {
    printf("%s\n", s);
  }

  return 0;
}
