/*
 * @author: Alex Cappiello
 * @date: 3/27/2013
 *
 * This file is intended to emphasize that malloc doesn't initialize memory to
 * zeros. calloc, on the other hand does. This doesn't mean you should always
 * use calloc though, since usually the first thing we do after allocating
 * memory is assigning something to it anyway.

 * Also, note the different definitions:
 *   void *malloc(size_t size);
 *   void *calloc(size_t nmemb, size_t size);
 * So, to make an array of 10 ints, I could call calloc(10, sizeof(int)) or
 * malloc(10 * sizeof(int)). size_t is a typedef for an unsigned int.
 *
 * Note that when I run this, I get the same block of memory back every
 * time. This is by no means guaranteed.
 */

#include <stdio.h>
#include <stdlib.h>

int main() {
  int *x = malloc(100 * sizeof(int));
  x[50] = 12;
  printf("%p %d\n", x, x[50]);
  free(x);

  x = malloc(100 * sizeof(int));
  printf("%p %d\n", x, x[50]);
  free(x);

  x = calloc(100, sizeof(int));
  printf("%p %d\n", x, x[50]);
  free(x);

  return 0;
}
