/*
 * @author: Alex Cappiello
 * @date: 4/6/2012
 *
 * This file is intended to show that we can access the value of a pointer
 * directly. With great power comes great responsibility.
 *
 * Try running it multiple times and see what happens.
 * Become familiar with printf, as it will be very useful for debugging.
 * It's much more versatile than the individual conio functions we're used to.
 */

// #include is the C equivalent of #use
#include <stdio.h> // This includes printf (among other things).
#include <stdlib.h> // This contains malloc and friends.

int main() {
  /* void* is a generic pointer to an undefined data type. Note that we can't
   * dereference a void* pointer, since we don't know what it is!
   *
   * Note that malloc takes in a size (number of bytes), not a type like alloc.
   * Use the sizeof() function to get the right number of bytes. Even though
   * we know how many bytes are in an int, use sizeof(), don't hardcode 4!
   */
  void *p = malloc(sizeof(int));

  // Print out the memory address.
  printf("%p\n", p);

  free(p); // Always free!

  return 0;
}
