/*
 * @author: Alex Cappiello
 * @date: 4/6/2012
 *
 * This file is intended to show a common case where we might overflow allocated
 * memory. Imagine a large text buffer instead of a small one.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int main() {
  // Don't worry about this declaration.
  const char x[] = "Hello World!!";

  // Maybe you don't know how long the input string is.
  char *s = malloc(5 * sizeof(char));

  /* Instead, we can write:
   * malloc((strlen(x) + 1) * sizeof(char));
   * Be careful. strlen does NOT include the nul terminator at the end of the
   * string. This is what the +1 accounts for. */

  strcpy(s, x);

  printf("%d %s\n", strlen(x), s);

  free(s); // Always free!

  return 0;
}
