/*
 * @author: Alex Cappiello
 * @date: 4/6/2012
 *
 * This file is intended to contrast strlen with strnlen. strnlen is useful to
 * make sure we don't overflow our buffer, since we can tell it how many
 * characters to copy, however, it does NOT automatically add a nul terminator
 * at the end. This can lead to nasty problems.
 * Compile as:
 *   gcc -std=c99 strncpy_fail.c
 * c99 mode is needed to declare a variable in a loop initialization.
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

int main() {
  /* This simulates memory usage as your program runs. Initially, the heap space
   * will likely be filled with zeros, but after we free a block of memory, it
   * can get allocated to something else, but the old data will still be there
   * (unless we use calloc). I simulate this by just using the same pointer in
   * the next step.
   */
  int *x = malloc(100 * sizeof(int)); // Initialize an array of 100 ints.
  for (int i = 0; i < 100; i++) {
    x[i] = 0xFFFFFFFF;
  }

  // Don't worry about the syntax of this declaration.
  // A char array declared like this has an implicit nul terminator.
  const char s[] = "Hello World!!";
  
  char *p = (char*)x;

  // Only copy the first 8 characters. Nul terminator does NOT get copied.
  strncpy(p, s, 8);

  printf("%s\n", p);
  
  free(x); // Always free!
  
  return 0;
}
